Class: Google::Cloud::Logging::V2::ConfigServiceV2Api

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/logging/v2/config_service_v2_api.rb

Overview

Service for configuring sinks used to export log entries outside Stackdriver Logging.

Constant Summary collapse

SERVICE_ADDRESS =

The default address of the service.

"logging.googleapis.com".freeze
DEFAULT_SERVICE_PORT =

The default port of the service.

443
CODE_GEN_NAME_VERSION =
"gapic/0.1.0".freeze
DEFAULT_TIMEOUT =
30
ALL_SCOPES =

The scopes needed to make gRPC calls to all of the methods defined in this service.

[
  "https://www.googleapis.com/auth/cloud-platform",
  "https://www.googleapis.com/auth/cloud-platform.read-only",
  "https://www.googleapis.com/auth/logging.admin",
  "https://www.googleapis.com/auth/logging.read",
  "https://www.googleapis.com/auth/logging.write"
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_path: SERVICE_ADDRESS, port: DEFAULT_SERVICE_PORT, channel: nil, chan_creds: nil, scopes: ALL_SCOPES, client_config: {}, timeout: DEFAULT_TIMEOUT, app_name: "gax", app_version: Google::Gax::VERSION) ⇒ ConfigServiceV2Api

Returns a new instance of ConfigServiceV2Api.

Parameters:

  • service_path (String) (defaults to: SERVICE_ADDRESS)

    The domain name of the API remote host.

  • port (Integer) (defaults to: DEFAULT_SERVICE_PORT)

    The port on which to connect to the remote host.

  • channel (Channel) (defaults to: nil)

    A Channel object through which to make calls.

  • chan_creds (Grpc::ChannelCredentials) (defaults to: nil)

    A ChannelCredentials for the setting up the RPC client.

  • client_config (Hash) (defaults to: {})

    A Hash for call options for each method. See Google::Gax#construct_settings for the structure of this data. Falls back to the default config if not specified or the specified config is missing data points.

  • timeout (Numeric) (defaults to: DEFAULT_TIMEOUT)

    The default timeout, in seconds, for calls made through this client.

  • app_name (String) (defaults to: "gax")

    The codename of the calling service.

  • app_version (String) (defaults to: Google::Gax::VERSION)

    The version of the calling service.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 144

def initialize \
    service_path: SERVICE_ADDRESS,
    port: DEFAULT_SERVICE_PORT,
    channel: nil,
    chan_creds: nil,
    scopes: ALL_SCOPES,
    client_config: {},
    timeout: DEFAULT_TIMEOUT,
    app_name: "gax",
    app_version: Google::Gax::VERSION
  google_api_client = "#{app_name}/#{app_version} " \
    "#{CODE_GEN_NAME_VERSION} ruby/#{RUBY_VERSION}".freeze
  headers = { :"x-goog-api-client" => google_api_client }
  client_config_file = Pathname.new(__dir__).join(
    "config_service_v2_client_config.json"
  )
  defaults = client_config_file.open do |f|
    Google::Gax.construct_settings(
      "google.logging.v2.ConfigServiceV2",
      JSON.parse(f.read),
      client_config,
      Google::Gax::Grpc::STATUS_CODE_NAMES,
      timeout,
      page_descriptors: PAGE_DESCRIPTORS,
      errors: Google::Gax::Grpc::API_ERRORS,
      kwargs: headers
    )
  end
  @stub = Google::Gax::Grpc.create_stub(
    service_path,
    port,
    chan_creds: chan_creds,
    channel: channel,
    scopes: scopes,
    &Google::Logging::V2::ConfigServiceV2::Stub.method(:new)
  )

  @list_sinks = Google::Gax.create_api_call(
    @stub.method(:list_sinks),
    defaults["list_sinks"]
  )
  @get_sink = Google::Gax.create_api_call(
    @stub.method(:get_sink),
    defaults["get_sink"]
  )
  @create_sink = Google::Gax.create_api_call(
    @stub.method(:create_sink),
    defaults["create_sink"]
  )
  @update_sink = Google::Gax.create_api_call(
    @stub.method(:update_sink),
    defaults["update_sink"]
  )
  @delete_sink = Google::Gax.create_api_call(
    @stub.method(:delete_sink),
    defaults["delete_sink"]
  )
end

Instance Attribute Details

#stubGoogle::Logging::V2::ConfigServiceV2::Stub (readonly)



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 40

class ConfigServiceV2Api
  attr_reader :stub

  # The default address of the service.
  SERVICE_ADDRESS = "logging.googleapis.com".freeze

  # The default port of the service.
  DEFAULT_SERVICE_PORT = 443

  CODE_GEN_NAME_VERSION = "gapic/0.1.0".freeze

  DEFAULT_TIMEOUT = 30

  PAGE_DESCRIPTORS = {
    "list_sinks" => Google::Gax::PageDescriptor.new(
      "page_token",
      "next_page_token",
      "sinks")
  }.freeze

  private_constant :PAGE_DESCRIPTORS

  # The scopes needed to make gRPC calls to all of the methods defined in
  # this service.
  ALL_SCOPES = [
    "https://www.googleapis.com/auth/cloud-platform",
    "https://www.googleapis.com/auth/cloud-platform.read-only",
    "https://www.googleapis.com/auth/logging.admin",
    "https://www.googleapis.com/auth/logging.read",
    "https://www.googleapis.com/auth/logging.write"
  ].freeze

  PARENT_PATH_TEMPLATE = Google::Gax::PathTemplate.new(
    "projects/{project}"
  )

  private_constant :PARENT_PATH_TEMPLATE

  SINK_PATH_TEMPLATE = Google::Gax::PathTemplate.new(
    "projects/{project}/sinks/{sink}"
  )

  private_constant :SINK_PATH_TEMPLATE

  # Returns a fully-qualified parent resource name string.
  # @param project [String]
  # @return [String]
  def self.parent_path project
    PARENT_PATH_TEMPLATE.render(
      :"project" => project
    )
  end

  # Returns a fully-qualified sink resource name string.
  # @param project [String]
  # @param sink [String]
  # @return [String]
  def self.sink_path project, sink
    SINK_PATH_TEMPLATE.render(
      :"project" => project,
      :"sink" => sink
    )
  end

  # Parses the project from a parent resource.
  # @param parent_name [String]
  # @return [String]
  def self.match_project_from_parent_name parent_name
    PARENT_PATH_TEMPLATE.match(parent_name)["project"]
  end

  # Parses the project from a sink resource.
  # @param sink_name [String]
  # @return [String]
  def self.match_project_from_sink_name sink_name
    SINK_PATH_TEMPLATE.match(sink_name)["project"]
  end

  # Parses the sink from a sink resource.
  # @param sink_name [String]
  # @return [String]
  def self.match_sink_from_sink_name sink_name
    SINK_PATH_TEMPLATE.match(sink_name)["sink"]
  end

  # @param service_path [String]
  #   The domain name of the API remote host.
  # @param port [Integer]
  #   The port on which to connect to the remote host.
  # @param channel [Channel]
  #   A Channel object through which to make calls.
  # @param chan_creds [Grpc::ChannelCredentials]
  #   A ChannelCredentials for the setting up the RPC client.
  # @param client_config[Hash]
  #   A Hash for call options for each method. See
  #   Google::Gax#construct_settings for the structure of
  #   this data. Falls back to the default config if not specified
  #   or the specified config is missing data points.
  # @param timeout [Numeric]
  #   The default timeout, in seconds, for calls made through this client.
  # @param app_name [String]
  #   The codename of the calling service.
  # @param app_version [String]
  #   The version of the calling service.
  def initialize \
      service_path: SERVICE_ADDRESS,
      port: DEFAULT_SERVICE_PORT,
      channel: nil,
      chan_creds: nil,
      scopes: ALL_SCOPES,
      client_config: {},
      timeout: DEFAULT_TIMEOUT,
      app_name: "gax",
      app_version: Google::Gax::VERSION
    google_api_client = "#{app_name}/#{app_version} " \
      "#{CODE_GEN_NAME_VERSION} ruby/#{RUBY_VERSION}".freeze
    headers = { :"x-goog-api-client" => google_api_client }
    client_config_file = Pathname.new(__dir__).join(
      "config_service_v2_client_config.json"
    )
    defaults = client_config_file.open do |f|
      Google::Gax.construct_settings(
        "google.logging.v2.ConfigServiceV2",
        JSON.parse(f.read),
        client_config,
        Google::Gax::Grpc::STATUS_CODE_NAMES,
        timeout,
        page_descriptors: PAGE_DESCRIPTORS,
        errors: Google::Gax::Grpc::API_ERRORS,
        kwargs: headers
      )
    end
    @stub = Google::Gax::Grpc.create_stub(
      service_path,
      port,
      chan_creds: chan_creds,
      channel: channel,
      scopes: scopes,
      &Google::Logging::V2::ConfigServiceV2::Stub.method(:new)
    )

    @list_sinks = Google::Gax.create_api_call(
      @stub.method(:list_sinks),
      defaults["list_sinks"]
    )
    @get_sink = Google::Gax.create_api_call(
      @stub.method(:get_sink),
      defaults["get_sink"]
    )
    @create_sink = Google::Gax.create_api_call(
      @stub.method(:create_sink),
      defaults["create_sink"]
    )
    @update_sink = Google::Gax.create_api_call(
      @stub.method(:update_sink),
      defaults["update_sink"]
    )
    @delete_sink = Google::Gax.create_api_call(
      @stub.method(:delete_sink),
      defaults["delete_sink"]
    )
  end

  # Service calls

  # Lists sinks.
  #
  # @param parent [String]
  #   Required. The resource name containing the sinks.
  #   Example: +"projects/my-logging-project"+.
  # @param page_size [Integer]
  #   The maximum number of resources contained in the underlying API
  #   response. If page streaming is performed per-resource, this
  #   parameter does not affect the return value. If page streaming is
  #   performed per-page, this determines the maximum number of
  #   resources in a page.
  # @param options [Google::Gax::CallOptions]
  #   Overrides the default settings for this call, e.g, timeout,
  #   retries, etc.
  # @return [Google::Gax::PagedEnumerable<Google::Logging::V2::LogSink>]
  #   An enumerable of Google::Logging::V2::LogSink instances.
  #   See Google::Gax::PagedEnumerable documentation for other
  #   operations such as per-page iteration or access to the response
  #   object.
  # @raise [Google::Gax::GaxError] if the RPC is aborted.
  def list_sinks \
      parent,
      page_size: nil,
      options: nil
    req = Google::Logging::V2::ListSinksRequest.new(
      parent: parent
    )
    req.page_size = page_size unless page_size.nil?
    @list_sinks.call(req, options)
  end

  # Gets a sink.
  #
  # @param sink_name [String]
  #   The resource name of the sink to return.
  #   Example: +"projects/my-project-id/sinks/my-sink-id"+.
  # @param options [Google::Gax::CallOptions]
  #   Overrides the default settings for this call, e.g, timeout,
  #   retries, etc.
  # @return [Google::Logging::V2::LogSink]
  # @raise [Google::Gax::GaxError] if the RPC is aborted.
  def get_sink \
      sink_name,
      options: nil
    req = Google::Logging::V2::GetSinkRequest.new(
      sink_name: sink_name
    )
    @get_sink.call(req, options)
  end

  # Creates a sink.
  #
  # @param parent [String]
  #   The resource in which to create the sink.
  #   Example: +"projects/my-project-id"+.
  #
  #   The new sink must be provided in the request.
  # @param sink [Google::Logging::V2::LogSink]
  #   The new sink, which must not have an identifier that already
  #   exists.
  # @param options [Google::Gax::CallOptions]
  #   Overrides the default settings for this call, e.g, timeout,
  #   retries, etc.
  # @return [Google::Logging::V2::LogSink]
  # @raise [Google::Gax::GaxError] if the RPC is aborted.
  def create_sink \
      parent,
      sink,
      options: nil
    req = Google::Logging::V2::CreateSinkRequest.new(
      parent: parent,
      sink: sink
    )
    @create_sink.call(req, options)
  end

  # Creates or updates a sink.
  #
  # @param sink_name [String]
  #   The resource name of the sink to update.
  #   Example: +"projects/my-project-id/sinks/my-sink-id"+.
  #
  #   The updated sink must be provided in the request and have the
  #   same name that is specified in +sinkName+.  If the sink does not
  #   exist, it is created.
  # @param sink [Google::Logging::V2::LogSink]
  #   The updated sink, whose name must be the same as the sink
  #   identifier in +sinkName+.  If +sinkName+ does not exist, then
  #   this method creates a new sink.
  # @param options [Google::Gax::CallOptions]
  #   Overrides the default settings for this call, e.g, timeout,
  #   retries, etc.
  # @return [Google::Logging::V2::LogSink]
  # @raise [Google::Gax::GaxError] if the RPC is aborted.
  def update_sink \
      sink_name,
      sink,
      options: nil
    req = Google::Logging::V2::UpdateSinkRequest.new(
      sink_name: sink_name,
      sink: sink
    )
    @update_sink.call(req, options)
  end

  # Deletes a sink.
  #
  # @param sink_name [String]
  #   The resource name of the sink to delete.
  #   Example: +"projects/my-project-id/sinks/my-sink-id"+.
  # @param options [Google::Gax::CallOptions]
  #   Overrides the default settings for this call, e.g, timeout,
  #   retries, etc.
  # @raise [Google::Gax::GaxError] if the RPC is aborted.
  def delete_sink \
      sink_name,
      options: nil
    req = Google::Logging::V2::DeleteSinkRequest.new(
      sink_name: sink_name
    )
    @delete_sink.call(req, options)
  end
end

Class Method Details

.match_project_from_parent_name(parent_name) ⇒ String

Parses the project from a parent resource.

Parameters:

  • parent_name (String)

Returns:

  • (String)


107
108
109
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 107

def self.match_project_from_parent_name parent_name
  PARENT_PATH_TEMPLATE.match(parent_name)["project"]
end

.match_project_from_sink_name(sink_name) ⇒ String

Parses the project from a sink resource.

Parameters:

  • sink_name (String)

Returns:

  • (String)


114
115
116
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 114

def self.match_project_from_sink_name sink_name
  SINK_PATH_TEMPLATE.match(sink_name)["project"]
end

.match_sink_from_sink_name(sink_name) ⇒ String

Parses the sink from a sink resource.

Parameters:

  • sink_name (String)

Returns:

  • (String)


121
122
123
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 121

def self.match_sink_from_sink_name sink_name
  SINK_PATH_TEMPLATE.match(sink_name)["sink"]
end

.parent_path(project) ⇒ String

Returns a fully-qualified parent resource name string.

Parameters:

  • project (String)

Returns:

  • (String)


87
88
89
90
91
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 87

def self.parent_path project
  PARENT_PATH_TEMPLATE.render(
    :"project" => project
  )
end

.sink_path(project, sink) ⇒ String

Returns a fully-qualified sink resource name string.

Parameters:

  • project (String)
  • sink (String)

Returns:

  • (String)


97
98
99
100
101
102
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 97

def self.sink_path project, sink
  SINK_PATH_TEMPLATE.render(
    :"project" => project,
    :"sink" => sink
  )
end

Instance Method Details

#create_sink(parent, sink, options: nil) ⇒ Google::Logging::V2::LogSink

Creates a sink.

Parameters:

  • parent (String)

    The resource in which to create the sink. Example: “projects/my-project-id”.

    The new sink must be provided in the request.

  • sink (Google::Logging::V2::LogSink)

    The new sink, which must not have an identifier that already exists.

  • options (Google::Gax::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Returns:

Raises:

  • (Google::Gax::GaxError)

    if the RPC is aborted.



270
271
272
273
274
275
276
277
278
279
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 270

def create_sink \
    parent,
    sink,
    options: nil
  req = Google::Logging::V2::CreateSinkRequest.new(
    parent: parent,
    sink: sink
  )
  @create_sink.call(req, options)
end

#delete_sink(sink_name, options: nil) ⇒ Object

Deletes a sink.

Parameters:

  • sink_name (String)

    The resource name of the sink to delete. Example: “projects/my-project-id/sinks/my-sink-id”.

  • options (Google::Gax::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Raises:

  • (Google::Gax::GaxError)

    if the RPC is aborted.



319
320
321
322
323
324
325
326
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 319

def delete_sink \
    sink_name,
    options: nil
  req = Google::Logging::V2::DeleteSinkRequest.new(
    sink_name: sink_name
  )
  @delete_sink.call(req, options)
end

#get_sink(sink_name, options: nil) ⇒ Google::Logging::V2::LogSink

Gets a sink.

Parameters:

  • sink_name (String)

    The resource name of the sink to return. Example: “projects/my-project-id/sinks/my-sink-id”.

  • options (Google::Gax::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Returns:

Raises:

  • (Google::Gax::GaxError)

    if the RPC is aborted.



246
247
248
249
250
251
252
253
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 246

def get_sink \
    sink_name,
    options: nil
  req = Google::Logging::V2::GetSinkRequest.new(
    sink_name: sink_name
  )
  @get_sink.call(req, options)
end

#list_sinks(parent, page_size: nil, options: nil) ⇒ Google::Gax::PagedEnumerable<Google::Logging::V2::LogSink>

Lists sinks.

Parameters:

  • parent (String)

    Required. The resource name containing the sinks. Example: “projects/my-logging-project”.

  • page_size (Integer) (defaults to: nil)

    The maximum number of resources contained in the underlying API response. If page streaming is performed per-resource, this parameter does not affect the return value. If page streaming is performed per-page, this determines the maximum number of resources in a page.

  • options (Google::Gax::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Returns:

  • (Google::Gax::PagedEnumerable<Google::Logging::V2::LogSink>)

    An enumerable of Google::Logging::V2::LogSink instances. See Google::Gax::PagedEnumerable documentation for other operations such as per-page iteration or access to the response object.

Raises:

  • (Google::Gax::GaxError)

    if the RPC is aborted.



225
226
227
228
229
230
231
232
233
234
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 225

def list_sinks \
    parent,
    page_size: nil,
    options: nil
  req = Google::Logging::V2::ListSinksRequest.new(
    parent: parent
  )
  req.page_size = page_size unless page_size.nil?
  @list_sinks.call(req, options)
end

#update_sink(sink_name, sink, options: nil) ⇒ Google::Logging::V2::LogSink

Creates or updates a sink.

Parameters:

  • sink_name (String)

    The resource name of the sink to update. Example: “projects/my-project-id/sinks/my-sink-id”.

    The updated sink must be provided in the request and have the same name that is specified in sinkName. If the sink does not exist, it is created.

  • sink (Google::Logging::V2::LogSink)

    The updated sink, whose name must be the same as the sink identifier in sinkName. If sinkName does not exist, then this method creates a new sink.

  • options (Google::Gax::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Returns:

Raises:

  • (Google::Gax::GaxError)

    if the RPC is aborted.



299
300
301
302
303
304
305
306
307
308
# File 'lib/google/cloud/logging/v2/config_service_v2_api.rb', line 299

def update_sink \
    sink_name,
    sink,
    options: nil
  req = Google::Logging::V2::UpdateSinkRequest.new(
    sink_name: sink_name,
    sink: sink
  )
  @update_sink.call(req, options)
end